@@ -2,15 +2,10 @@
 
 use strict;
 use warnings;
-
 use Math::Prime::Simple qw(prime each_prime);
 
-my (@ranges, $primes);
-
-@ranges = (  [ 10500, 10600 ],
-);
-          
-$primes = prime(\@ranges);
+my @ranges = ([ 10500, 10600 ]);         
+my $primes = prime(\@ranges);
 
 print <<'EOT';
 ------
@@ -22,5 +17,3 @@ EOT
 while (my $prime = each_prime(0, $primes)) {
     print "$prime\n";
 }
-
-print "\n";
